@@ -1,4 +1,5 @@
 from .logger import setup_logger
 from .pools import init_pools
 from .tf import setup_growth, set_tf_log_level, disable_tf_logs
-from .mem import log_mem_usage
\ No newline at end of file
+from .problem import ProblemUtils
+from .acquisition import beta_approximated_upper_joint_entropy
\ No newline at end of file
